import React from 'react';
import { TouchableOpacity, View } from 'react-native';
import AsyncStorage from '@react-native-async-storage/async-storage';
import { addFontList } from 'muba-font';
import PopupAdvice from 'muba-popup-advice';
import OutputText from 'muba-output-text';
import { strings, loadLocaleData } from 'muba-i18n';
import { popupErrorStyles } from './PopupErrorStyles';
import { createIconSetFromFontello } from 'react-native-vector-icons';
import fontelloConfig from './fonts/config.json';
const FontAwesomeIcon = createIconSetFromFontello(fontelloConfig);

export const ERROR_POPUP = 'errorPopup';

export default class PopupError extends React.Component {
  constructor(props) {
    super(props);

    loadLocaleData({
      ar: require('./locales/ar.json'),
      en: require('./locales/en.json'),
      es: require('./locales/es.json'),
      fr: require('./locales/fr.json'),
      it: require('./locales/it.json'),
      nl: require('./locales/nl.json')
    });

    this.state = ({
      fontLoaded: false
    });
  }

  async componentDidMount() {
    this.popupError.show();
    AsyncStorage.setItem(ERROR_POPUP, 'true');

    await addFontList([
      {
        name: 'PopupErrorBold',
        source: require('./fonts/Poppins/Poppins-Bold.ttf')
      },
      {
        name: 'PopupErrorSemiBold',
        source: require('./fonts/Poppins/Poppins-SemiBold.ttf')
      },
      {
        name: 'PopupErrorRegular',
        source: require('./fonts/Poppins/Poppins-Regular.ttf')
      },
      {
        name: 'PopupErrorFontAwesome',
        source: require('./fonts/Font-Awesome.ttf')
      }
    ]);
    this.setState({ fontLoaded: true });
  }

  async componentWillUnmount() {
    await AsyncStorage.setItem(ERROR_POPUP, 'false');
  }

  async closePopup() {
    await AsyncStorage.setItem(ERROR_POPUP, 'false');
    this.props.navigation.goBack()
  }

  render() {
    let titleIcon = <View />;
    if (this.state.fontLoaded) {
      titleIcon = <FontAwesomeIcon style={[popupErrorStyles.popupTitle, popupErrorStyles.marginNeg, popupErrorStyles.redText]} name='popup-error-attention' />;
    }

    return (
      <PopupAdvice ref={(popupError) => { this.popupError = popupError; }} icon={titleIcon} title={this.props.title ? this.props.title : strings('genericError')}
        headerColor={popupErrorStyles.redText} hideButton={true} onClose={() => this.closePopup()}>
        {this.state.fontLoaded ?
          <View>
            <OutputText style={[popupErrorStyles.popupText, popupErrorStyles.popupTextError]}>{this.props.text ? this.props.text : strings('adviceError')}</OutputText>
            <TouchableOpacity style={[popupErrorStyles.okBtnBox, this.props.buttonColor ? this.props.buttonColor : popupErrorStyles.okBtn]} onPress={() => this.popupError.hide()} >
              {this.props.buttonText ?
                <OutputText style={popupErrorStyles.okBtnText}>{this.props.buttonText}</OutputText>
                :
                <OutputText style={popupErrorStyles.okBtnText}>{strings('adviceOK').toUpperCase()}</OutputText>
              }
            </TouchableOpacity>
          </View>
          :
          <View />
        }
      </PopupAdvice >
    );
  }
}